Name:       resourced
Summary:    Resource management daemon
Version:    5.5.2
Release:    1
Group:      System/Libraries
License:    Apache-2.0
Source0:    %{name}-%{version}.tar.gz

# Default setting
# Notice : to use freezer module, you should install system-freezer plugin
# Notice : if you want to change these variables for a profile, you need to
#       reset them at every end of cmake to reset to default value and
#       you should not use the variable except inside pushd/popd in build
#       section.
%define cpu_module			ON
%define memory_module		ON
%define mem_stress			OFF
%define vip_agent_module	ON

%define memory_eng			ON
%define debug_log			OFF

# Default settings changed per profile:
%define block_module		ON
%define freezer_module		ON
%define heart_module		ON
%define swap_module			ON

%define rd_config_path /etc/resourced

BuildRequires:  cmake
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(dlog)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(vconf)
BuildRequires:  pkgconfig(vconf-internal-keys)
BuildRequires:  pkgconfig(libsystemd)
BuildRequires:  pkgconfig(leveldb)
BuildRequires:  pkgconfig(eventsystem)
BuildRequires:  pkgconfig(capi-system-info)
BuildRequires:  pkgconfig(libtzplatform-config)
BuildRequires:  pkgconfig(storage)
BuildRequires:  pkgconfig(libgum)

#only for data types
BuildRequires:  pkgconfig(tapi)

Requires(post): /sbin/ldconfig
Requires(postun): /sbin/ldconfig
Requires(post): %{_sbindir}/update-alternatives
Requires(preun): %{_sbindir}/update-alternatives

BuildRequires:  gperf
%if %{?swap_module} == ON
Requires:   %{_sbindir}/mkswap
Requires:   %{_bindir}/dd
%endif
Provides:   %{name}-compat
Conflicts:  %{name}-light

%description
Resourced daemon.

%package light
Summary:	Resourced light binary
Provides:   %{name}-compat
Conflicts:	%{name}
Requires(post): %{_sbindir}/update-alternatives
Requires(preun): %{_sbindir}/update-alternatives
%description light
Resourced binary doing minimal features

%package config-tv
Summary:    Configration for tv profile
Requires:   %{name}-compat = %{version}-%{release}
%description config-tv
Rename configuration file for the TV profile

%package tests
Summary:    Tests for resrouced
Requires:   %{name}-compat
%description tests
This package contains tests for resourced.

%prep
%setup -q

%build
MAJORVER=`echo %{version} | awk 'BEGIN {FS="."}{print $1}'`
MINORVER=`echo %{version} | awk 'BEGIN {FS="."}{print $2}'`
PATCHVER=`echo %{version} | awk 'BEGIN {FS="."}{print $3}'`
echo "\
/* That file was generated automaticaly. Don't edit it */
#define MINOR_VERSION ${MINORVER}
#define MAJOR_VERSION ${MAJORVER}
#define PATCH_VERSION ${PATCHVER}" > src/common/version.h

export CFLAGS="$CFLAGS -DTIZEN_DEBUG_ENABLE"
export CXXFLAGS="$CXXFLAGS -DTIZEN_DEBUG_ENABLE"
export FFLAGS="$FFLAGS -DTIZEN_DEBUG_ENABLE"

%ifarch %{arm}
	%define ARCH armv7l
%else
	%ifarch aarch64
		%define ARCH arm64
	%else
		%ifarch %ix86
			%define ARCH i586
		%else
			%define ARCH x86_64
		%endif
	%endif
%endif

# For resourced-without_heart binary
mkdir -p build_light
pushd build_light
%define block_module		OFF
%define freezer_module		OFF
%define heart_module		OFF
%define swap_module			OFF

%cmake .. -DFULLVER=%{version} \
	 -DMAJORVER=${MAJORVER} \
	 -DARCH=%{ARCH} \
	 -DCMAKE_BUILD_TYPE=Release \
	 -DDATABASE_FULL_PATH=%{database_full_path} \
	 -DBLOCK_MODULE=%{block_module} \
	 -DCPU_MODULE=%{cpu_module} \
	 -DFREEZER_MODULE=%{freezer_module} \
	 -DHEART_MODULE=%{heart_module} \
	 -DMEMORY_MODULE=%{memory_module} \
	 -DMEM_STRESS=%{mem_stress} \
	 -DSWAP_MODULE=%{swap_module} \
	 -DVIP_AGENT=%{vip_agent_module} \
	 -DMEMORY_ENG=%{memory_eng} \
	 -DDEBUG_LOG=%{debug_log} \
	 -DDATAUSAGE_TYPE=NFACCT \
	 -DRD_SYS_HOME=%{TZ_SYS_HOME} \
	 -DRD_SYS_ETC=%{TZ_SYS_ETC} \
	 -DRD_SYS_DATA=%{TZ_SYS_GLOBALUSER_DATA} \
	 -DRD_SYS_DB=%{TZ_SYS_GLOBALUSER_DB} \
	 -DRD_CONFIG_PATH=%{rd_config_path} \
	 -DRD_BINARY_NAME=resourced.light

make %{?jobs:-j%jobs}
# Default settings changed per profile:
%define block_module		ON
%define freezer_module		ON
%define heart_module		ON
%define swap_module			ON

popd

# For resourced binary
%cmake . -DFULLVER=%{version} \
	 -DMAJORVER=${MAJORVER} \
	 -DARCH=%{ARCH} \
	 -DCMAKE_BUILD_TYPE=Release \
	 -DDATABASE_FULL_PATH=%{database_full_path} \
	 -DBLOCK_MODULE=%{block_module} \
	 -DCPU_MODULE=%{cpu_module} \
	 -DFREEZER_MODULE=%{freezer_module} \
	 -DHEART_MODULE=%{heart_module} \
	 -DMEMORY_MODULE=%{memory_module} \
	 -DMEM_STRESS=%{mem_stress} \
	 -DSWAP_MODULE=%{swap_module} \
	 -DVIP_AGENT=%{vip_agent_module} \
	 -DMEMORY_ENG=%{memory_eng} \
	 -DDEBUG_LOG=%{debug_log} \
	 -DDATAUSAGE_TYPE=NFACCT \
	 -DRD_SYS_HOME=%{TZ_SYS_HOME} \
	 -DRD_SYS_ETC=%{TZ_SYS_ETC} \
	 -DRD_SYS_DATA=%{TZ_SYS_GLOBALUSER_DATA} \
	 -DRD_SYS_DB=%{TZ_SYS_GLOBALUSER_DB} \
	 -DRD_CONFIG_PATH=%{rd_config_path} \
	 -DRD_TESTS_PATH=%{_libdir}/resourced-tests \
	 -DRD_BINARY_NAME=resourced.common

make %{?jobs:-j%jobs}

%install
rm -rf %{buildroot}

pushd build_light
%make_install
popd

%make_install
mkdir -p %{buildroot}/%{TZ_SYS_GLOBALUSER_DATA}/heart
mkdir -p %{buildroot}/%{TZ_SYS_GLOBALUSER_DB}

%pre

if [ "$1" = "2" ]; then # upgrade begins
	systemctl stop resourced.service
fi

%preun
if [ $1 -eq 0 ] ; then
	%{_sbindir}/update-alternatives --remove %{name} %{_bindir}/resourced.common
fi

%post

/sbin/ldconfig

#install init.d script
mkdir -p %{TZ_SYS_ETC}

if [ "$1" = "2" ]; then # upgrade begins
	systemctl start resourced.service
fi

%{_sbindir}/update-alternatives --install %{_bindir}/resourced %{name} %{_bindir}/resourced.common 100

%postun -p /sbin/ldconfig

%files
%license LICENSE
%ghost %{_bindir}/resourced
%attr(-,root, root) %{_bindir}/resourced.common
%manifest resourced.manifest
%config %{_sysconfdir}/dbus-1/system.d/resourced.conf
%{_unitdir}/resourced.service
%{_unitdir}/multi-user.target.wants/resourced.service
%if %{?memory_module} == ON
	%config %{rd_config_path}/memory.conf
%endif
%config %{rd_config_path}/proc.conf
%if %{?cpu_module} == ON
	%config %{rd_config_path}/cpu.conf
%endif
%if %{?swap_module} == ON
	%config %{rd_config_path}/swap.conf
%endif
%if %{?vip_agent_module} == ON
	%config %{rd_config_path}/vip-process.conf
	%attr(700,root, root) %{_bindir}/vip-release-agent
%endif
%if %{?block_module} == ON
	%config %{rd_config_path}/block.conf
%endif
%if %{?heart_module} == ON
	%config %{rd_config_path}/heart.conf
	%attr(700, root, root) %{TZ_SYS_ETC}/dump.d/module.d/dump_heart_data.sh
%endif
#mem-stress
%if %{?mem_stress} == ON
%attr(-,root, root) %{_bindir}/mem-stress
%{_unitdir}/mem-stress.service
%{_unitdir}/graphical.target.wants/mem-stress.service
%endif

%post light
%{_sbindir}/update-alternatives --install %{_bindir}/resourced %{name} %{_bindir}/resourced.light 100
%preun light
if [ $1 -eq 0 ] ; then
	%{_sbindir}/update-alternatives --remove %{name} %{_bindir}/resourced.light
fi

%files light
%license LICENSE
%ghost %{_bindir}/resourced
%attr(-,root, root) %{_bindir}/resourced.light
%manifest resourced.manifest
%config %{_sysconfdir}/dbus-1/system.d/resourced.conf
%{_unitdir}/resourced.service
%{_unitdir}/multi-user.target.wants/resourced.service
%if %{?memory_module} == ON
	%config %{rd_config_path}/memory.conf
%endif
%config %{rd_config_path}/proc.conf
%if %{?cpu_module} == ON
	%config %{rd_config_path}/cpu.conf
%endif
%if %{?vip_agent_module} == ON
	%config %{rd_config_path}/vip-process.conf
	%attr(700,root, root) %{_bindir}/vip-release-agent
%endif
#mem-stress
%if %{?mem_stress} == ON
%attr(-,root, root) %{_bindir}/mem-stress
%{_unitdir}/mem-stress.service
%{_unitdir}/graphical.target.wants/mem-stress.service
%endif

%pre config-tv
mv %{rd_config_path}/memory.conf %{rd_config_path}/memory_old.conf
%post config-tv
mv %{rd_config_path}/memory_tv.conf %{rd_config_path}/memory.conf
%preun config-tv
mv %{rd_config_path}/memory.conf %{rd_config_path}/memory_tv.conf
%postun config-tv
mv %{rd_config_path}/memory_old.conf %{rd_config_path}/memory.conf
%files config-tv
%if %{?memory_module} == ON
	%config %{rd_config_path}/memory_tv.conf
%endif

%files tests
%defattr(-,root,root)
%{_libdir}/resourced-tests/run_tests.sh
%{_libdir}/resourced-tests/watchdog-test
