/*
 * resourced
 * Copyright (c) 2017 Samsung Electronics Co., Ltd All Rights Reserved
 *
 * Licensed under the Apache License, Version 2.0 (the License);
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an AS IS BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */


#ifndef __FD_HANDLER_H__
#define __FD_HANDLER_H__

#include <glib.h>
#include <gio/gio.h>
#include <stdbool.h>

/**
 * @brief   File descriptor handler
 * @since_tizen 4.0
 */
typedef void *fd_handler_h;

/**
 * @brief   Type for the file descriptor change callback function
 * @since_tizen 4.0
 */
typedef bool (*fd_changed_cb)(int fd, void *data);

/**
 * @brief   Type of the callback function to release user data
 * @since_tizen 4.0
 */
typedef void (*release_cb)(void *data);

/**
 * @brief   Register file descriptor callback function
 * @since_tizen 4.0
 * @param[in]  fd    The file descriptor to notify the changes.
 * @param[in]  callback The callback function which will be called when the fd is changed.
 * @param[in]  data  The user data which is delivered to the callback function.
 * @param[in]  free_func  The callback function to release the user data which is called when the handler is removed by remove_fd_read_handler().
 * @param[out] handler The handler which will be used to remove the fd handler.
 * @return  @c 0 on success,
 *          otherwise a negative error value
 * @remarks If the callback function returns false, the fd handler is removed automatically and the callback will not be called again.
 */
int add_fd_read_handler(int fd, fd_changed_cb callback,
		void *data, release_cb free_func,
		fd_handler_h *handler);

/**
 * @brief   Unregister file descriptor callback function
 * @since_tizen 4.0
 * @param[in]  handler    The fd handler which is obtained by add_fd_read_handler().
 * @return  @c 0 on success,
 *          otherwise a negative error value
 */
int remove_fd_read_handler(fd_handler_h *handler);

#endif /* __FD_HANDLER_H__ */
