/*
 * resourced
 *
 * Copyright (c) 2013 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

/**
 * @file swap-common.h
 * @desc swap common process
 **/

#ifndef __SWAP_COMMON_H__
#define __SWAP_COMMON_H__

#include <stdio.h>
#include "resourced.h"
#include "memory-common.h"

#define SWAP_ZRAM_SYSFILE	"/sys/block/zram0/"
#define SWAP_FILE_NAME		"/opt/usr/.swapfile"
#define SWAP_CONF_FILE		RD_CONFIG_FILE(swap)

enum swap_state {
	SWAP_ARG_START = -1,
	SWAP_OFF,
	SWAP_ON,
	SWAP_ARG_END,
};

enum swap_type {
	SWAP_TYPE_NONE = 0x0,
	SWAP_TYPE_ZRAM = 0x1,
	SWAP_TYPE_FILE = 0x2,
	SWAP_TYPE_ZSWAP = 0x4,
	SWAP_TYPE_MAX,
};

struct swap_status_msg {
	enum memcg_type type;
	struct memcg_info *info;
	pid_t pid;
};

enum swap_compact_reason {
	SWAP_COMPACT_LOWMEM_LOW,
	SWAP_COMPACT_LOWMEM_MEDIUM,
	SWAP_COMPACT_SWAP_FULL,
	SWAP_COMPACT_RESASON_MAX,
};

/*
 * Each swap modoule can have priority.
 * The swap list of kernel has low-to-high order
 * while swap ordering is high-to-low.
 * So, if a swap module has lower priority, it should be intialized eariler.
 * On the top of that, SWAP_PRI_DISABLE will be used
 * not to support multiple swap devices.
 */
enum swap_priority {
	SWAP_PRI_DISABLE = -255,
	SWAP_PRI_LOW = -1,
	SWAP_PRI_DEFAULT = 0,
	SWAP_PRI_HIGH = 1,
};

#ifdef SWAP_SUPPORT
enum swap_state swap_get_state(void);
#else
static inline enum swap_state swap_get_state(void)
{
	return SWAP_OFF;
}
#endif

struct swap_module_ops {
	char *name;
	enum swap_type type;
	char *path;
	int priority;
	unsigned int k_size;
	int (*init)(void *data);
	int (*exit) (void *data);
	int (*activate)(void *data);
	int (*reclaim)(void *data);
};


int swap_set_file(char *file, struct swap_module_ops *swap, char *crypt_type);
int do_mkswap(const char *device);
int do_dd(char *input, char *output, unsigned int size, unsigned int count);

bool swap_is_on(const char *name);

void swap_add(const struct swap_module_ops *swap);
void swap_remove(const struct swap_module_ops *swap);

#define SWAP_MODULE_REGISTER(swap)					\
static void __attribute__ ((constructor)) swap_module_register(void)		\
{							\
	swap_add(swap);					\
}							\
static void __attribute__ ((destructor)) swap_module_unregister(void)	\
{							\
	swap_remove(swap);				\
}

#endif /* __SWAP_COMMON_H__ */
