/*
 * resourced
 *
 * Copyright (c) 2016 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

/**
 * @file userinfo-list.h
 * @desc define helper functions to get user info.
 **/

#ifndef __USERINFO_LIST_H__
#define __USERINFO_LIST_H__

#include <linux/limits.h>
#include <glib.h>

#include "resourced.h"

#define userinfo_for_each(elem, list)	\
	guint _ui_idx;	\
	struct user_info *elem;	\
	for (_ui_idx = 0;	\
		_ui_idx < list->len && (elem = g_array_index(list, struct user_info*, _ui_idx));	\
		_ui_idx++)	\

struct user_info {
	uid_t uid;
	char home_dir[PATH_MAX];
};

/**
 * @brief          Find home directory
 * @detail         Return home directory of the user having uid
 * @param[in] uid  UID of user
 * @retval NULL    Fail to find
 * @retval else    Home directory of user
 */
const char *userinfo_find_home_dir(uid_t uid);

/**
 * @brief        Get user_list
 * @detail       Return user_list(pid, home_dir) after updating
 * @retval NULL  Fail to get user_list
 * @retval else  user_list
 */
const GArray *userinfo_get_list(void);

#endif /*__USERINFO_LIST_H__*/
