/*
 * resourced
 *
 * Copyright (c) 2017 Samsung Electronics Co., Ltd. All rights reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 *
 */

/**
 * @file proc-usgae-stats.h
 * @desc Handles the dbus method calls made by the runtime-info APIs
 **/

#ifndef __PROC_USAGE_STATS_H__
#define __PROC_USAGE_STATS_H__

#include <gio/gio.h>

/**
 * @brief       DBus method to return the memory usage information of input processes
 * @since_tizen 2.4
 *
 * @param[in] invocation       The dbus invocation
 * @param[in] params	Parameters sent by the runtime info API
 * 			This should be an array of process IDs.
 *
 * @retval              The response dbus contains an array of structs
 *			(structure similar to process_memory_info_s). The structs contain the
 *			memory usage info fields for the processes (in the same order).
 *			For invalid process IDs, the fields of the process_memory_info_s struct
 *			will be set to INVALID_PROCESS_INFO_FIELD_VALUE.
 *			If the input dbus message does not contain array of integers or if there
 *			are errors in computation, collection and sending of usage info, then the
 *			response dbus message contains only an integer whose value will the error value.
 */
void dbus_proc_memory_usage(GDBusMethodInvocation *invocation, GVariant *params);

/**
 * @brief       DBus method to return the cpu usage information of input processes
 * @since_tizen 2.4
 *
 * @param[in] invocation       The dbus invocation
 * @param[in] params	Parameters sent by the runtime info API
 * 			This should be an array of process IDs.
 *
 * @retval              The response contains an array of structs
 *			(structure similar to process_cpu_usage_s). The structs contain the
 *			cpu usage info fields for the processes (in the same order).
 *			For invalid process IDs, the fields of the process_cpu_usage_s struct
 *			will be set to INVALID_PROCESS_INFO_FIELD_VALUE.
 *			If the input dbus message does not contain array of integers or if there
 *			are errors in computation, collection and sending of usage info, then the
 *			response dbus message contains only an integer whose value will the error value.
 */
void dbus_proc_cpu_usage(GDBusMethodInvocation *invocation, GVariant *params);

#endif /* __PROC_USAGE_STATS_H__ */
